const axios = require('axios');
const { translateText } = require('../plugins/translator');
const dotenv = require('dotenv');

dotenv.config();

const AUTHORIZED_NUMBER = process.env.AUTHORIZED_NUMBER;

/**
 * Obtiene una cita de estoicismo de la API y la traduce al español.
 * @returns {Promise<String>} - Cita traducida al español.
 */
const getStoicQuote = async () => {
    try {
        const response = await axios.get('https://stoic.tekloon.net/stoic-quote');
        const { author, quote } = response.data.data;

        // Traducir la cita al español
        const translatedQuote = await translateText(quote, 'es');
        
        // Formato mejorado para WhatsApp
        return `━━━━━━━━━━━━━━━\n` +
               `🧘‍♂️ *REMINDER* 🧘‍♀️\n\n` +
               `\n${translatedQuote}\n\n` +
               `*- ${author}*\n` +
               `━━━━━━━━━━━━━━━`;
    } catch (error) {
        console.error('Error al obtener la cita de estoicismo:', error);
        return '❌ Hubo un problema al obtener la cita de estoicismo.';
    }
};

/**
 * Envía una cita de estoicismo traducida al español al número autorizado.
 * @param {Object} client - Instancia del cliente de WhatsApp.
 */
const sendStoicReminder = async (client) => {
    const quoteMessage = await getStoicQuote();
    try {
        await client.sendMessage(AUTHORIZED_NUMBER, quoteMessage);
        console.log(`📤 Cita de estoicismo enviada a ${AUTHORIZED_NUMBER}`);
    } catch (error) {
        console.error('❌ Error al enviar la cita de estoicismo:', error);
    }
};

module.exports = {
    sendStoicReminder,
    getStoicQuote
};
